package HT.fx;

public class Pelaajat {
    private static final int Max_Pelaajat   = 9;
    private int lkm           = 0;
    private String tiedostonNimi = "";
    private Pelaaja alkiot[]      = new Pelaaja[Max_Pelaajat];
    
    /**
     * Oletusmuodostaja
     */
    public Pelaajat() {
        // Attribuuttien oma alustus riittää
    }
    
    /**
     * @param pelaaja pelaaja
     * @throws SailoException exception kun rakenne täysi
     * @example
     * <pre name="test">
     * #THROWS SailoException 
     * Pelaajat pelaajat = new Pelaajat();
     * Pelaaja aku1 = new Pelaaja(), aku2 = new Pelaaja();
     * pelaajat.getLkm() === 0;
     * pelaajat.lisaa(aku1); pelaajat.getLkm() === 1;
     * pelaajat.lisaa(aku2); pelaajat.getLkm() === 2;
     * pelaajat.lisaa(aku1); pelaajat.getLkm() === 3;
     * pelaajat.anna(0) === aku1;
     * pelaajat.anna(1) === aku2;
     * pelaajat.anna(2) === aku1;
     * pelaajat.anna(1) == aku1 === false;
     * pelaajat.anna(1) == aku2 === true;
     * pelaajat.anna(3) === aku1; #THROWS IndexOutOfBoundsException 
     * pelaajat.lisaa(aku1); pelaajat.getLkm() === 4;
     * pelaajat.lisaa(aku1); pelaajat.getLkm() === 5;
     * pelaajat.lisaa(aku1);  #THROWS SailoException
     * </pre>
     */
    public void lisaa(Pelaaja pelaaja) throws SailoException {
        if (lkm >= alkiot.length) throw new SailoException("Liikaa alkioita");
        alkiot[lkm] = pelaaja;
        lkm++;
    }
    
    /**
     * Palauttaa viitteen iinteen jäseneen.
     * @param i monennenko jäsenen viite halutaan
     * @return viite jäseneen, jonka indeksi on i
     * @throws IndexOutOfBoundsException jos i ei ole sallitulla alueella  
     */
    public Pelaaja anna(int i) throws IndexOutOfBoundsException {
        if (i < 0 || lkm <= i)
            throw new IndexOutOfBoundsException("Laiton indeksi: " + i);
        return alkiot[i];
    }
    
    /**
     * Lukee påelaajiston tiedostosta.  Ei toimi.
     * @param tiedosto tiedoston hakemisto
     * @throws SailoException jos lukeminen epäonnistuu
     */
    public void lueTiedostosta(String tiedosto) throws SailoException {
        tiedostonNimi = tiedosto + "/nimet.dat";
        throw new SailoException("Ei osata vielä lukea tiedostoa " + tiedostonNimi);
    }
    
    /**
     * Tallentaa pelaajiston tiedostoon.  Ei toimi.
     * @throws SailoException jos talletus epäonnistuu
     */
    public void talleta() throws SailoException {
        throw new SailoException("Ei osata vielä tallettaa tiedostoa " + tiedostonNimi);
    }
    
    /**
     * Palauttaa jäsenten lukumäärän
     * @return jäsenten lukumäärä
     */
    public int getLkm() {
        return lkm;
    }
    
    /**
     * Testiohjelma jäsenistölle
     * @param args ei käytössä
     */
    public static void main(String args[]) {
        Pelaajat pelaajat = new Pelaajat();

      Pelaaja aku = new Pelaaja(), aku2 = new Pelaaja();
        aku.rekisteroi();
        aku.vastaaAkuAnkka();
        aku2.rekisteroi();
        aku2.vastaaAkuAnkka();

        try {
            pelaajat.lisaa(aku);
            pelaajat.lisaa(aku2);

            System.out.println("============= Jäsenet testi =================");

            for (int i = 0; i < pelaajat.getLkm(); i++) {
                Pelaaja pelaaja = pelaajat.anna(i);
                System.out.println("Pelaaja nro: " + i);
                pelaaja.tulosta(System.out);
            }

        } catch (SailoException ex) {
            System.out.println(ex.getMessage());
        }
    }
}
